//  Copyright 2021 Nikita Golikov

#include <bits/stdc++.h>

using namespace std;

using uint = unsigned int;
using ll = long long;
using ull = unsigned long long;

#ifdef GOLIKOV
    #define debug(x) cerr << (#x) << ":\t" << (x) << endl
#else
    #define debug(x) 238;
#endif

template <class A, class B>
bool smin(A &x, B &&y) {
  if (y < x) {
    x = y;
    return true;
  }
  return false;
}

template <class A, class B>
bool smax(A &x, B &&y) {
  if (x < y) {
    x = y;
    return true;
  }
  return false;
}

void solveTest() {
  int n, m;
  cin >> n >> m;
  vector<int> times;
  vector<int> a(n);
  times.push_back(0);
  times.push_back(m - 1);
  for (auto& x : a) {
    cin >> x;
    times.push_back((m - x % m) % m);
  }

  static int const INF = -1e8;

  struct node {
    pair<int, int> mx{INF, -1};
    int toadd{};
    int toset = -1;

    node operator+(node const& other) const {
      node res{};
      res.mx = max(mx, other.mx);
      return res;
    }

    void applyAdd(int add) {
      toadd += add;
      mx.first += add;
    }

    void applySet(int val) {
      toadd = 0;
      toset = val;
      mx.first = val;
    }
  };
  sort(times.begin(), times.end());
  times.erase(unique(times.begin(), times.end()), times.end());

  auto getid = [&](int t) {
    return int(lower_bound(times.begin(), times.end(), t) - times.begin());
  };

  int nt = int(times.size());
  int pw = 1;
  while (pw < nt) pw *= 2;
  vector<node> tree(2 * pw);
  for (int i = 0; i < nt; ++i) {
    tree[pw + i].mx = make_pair(0, ~i);
  }
  for (int i = pw - 1; i > 0; --i) {
    tree[i] = tree[2 * i] + tree[2 * i + 1];
  }

  auto push = [&](int v) {
    if (tree[v].toset != -1) {
      tree[2 * v].applySet(tree[v].toset);
      tree[2 * v + 1].applySet(tree[v].toset);
      tree[v].toset = -1;
    }
    if (tree[v].toadd != 0) {
      tree[2 * v].applyAdd(tree[v].toadd);
      tree[2 * v + 1].applyAdd(tree[v].toadd);
      tree[v].toadd = 0;
    }
  };
  auto updSet = [&](int ql, int qr, int val) {
    auto rec = [&](auto&& self, int v, int l, int r) -> void {
      if (ql >= r || l >= qr) {
        return;
      }
      if (ql <= l && r <= qr) {
        tree[v].applySet(val);
        return;
      }
      int mid = (l + r) / 2;
      push(v);
      self(self, 2 * v, l, mid);
      self(self, 2 * v + 1, mid, r);
      tree[v] = tree[2 * v] + tree[2 * v + 1];
    };
    rec(rec, 1, 0, pw);
  };
  auto updAdd = [&](int ql, int qr, int d) {
    auto rec = [&](auto&& self, int v, int l, int r) -> void {
      if (ql >= r || l >= qr) {
        return;
      }
      if (ql <= l && r <= qr) {
        tree[v].applyAdd(d);
        return;
      }
      int mid = (l + r) / 2;
      push(v);
      self(self, 2 * v, l, mid);
      self(self, 2 * v + 1, mid, r);
      tree[v] = tree[2 * v] + tree[2 * v + 1];
    };
    rec(rec, 1, 0, pw);
  };

  pair<int, int> ans{INF, -1};

  auto updAns = [&] {
    smax(ans, tree[1].mx);
  };

  updAdd(0, nt, 1);
  updAns();

  for (int i = 1; i < n; ++i) {
    int x = a[i - 1];
    int y = a[i];
    int mx = (m - x % m) % m;
    int my = (m - y % m) % m;

    int moment1 = getid(min(mx, my));
    int moment2 = getid(max(mx, my));

    auto process = [&](int l, int r, int d) {
      // debug(i);
      // debug(d);
      // debug(x);
      // debug(y);
      int me = (x + d) / m;
      int he = (y + d) / m;
      // debug(me);
      // debug(he);
      // debug(l);
      // debug(r);
      if (me == he) {
        return;
      }
      if (he == me + 1) {
        // cerr << "add " << l << ' ' << r << '\n';
        updAdd(l, r, 1);
      } else {
        // cerr << "set " << l << ' ' << r << '\n';
        updSet(l, r, 1);
      }
    };

    process(moment1, moment2, times[moment1]);
    // updAns();
    process(moment2, nt, times[moment2]);
    // updAns();
    process(0, moment1, times[0]);
    // updAns();

    updAns();
  }

  cout << ans.first << ' ' << times[~ans.second] << '\n';
}

int main() {
#ifdef GOLIKOV
  assert(freopen("in", "rt", stdin));
  auto _clock_start = chrono::high_resolution_clock::now();
#endif
  ios::sync_with_stdio(false);
  cin.tie(nullptr);

  int _tests;
  cin >> _tests;
  for (int _tt = 1; _tt <= _tests; ++_tt) {
    solveTest();
  }

#ifdef GOLIKOV
  cerr << "Executed in " << chrono::duration_cast<chrono::milliseconds>(
      chrono::high_resolution_clock::now()
          - _clock_start).count() << "ms." << endl;
#endif
  return 0;
}
