#include <bits/stdc++.h>

using namespace std;

using ll = long long;
using ui = unsigned int;
using ull = unsigned long long;
using ld = long double;
using pii = pair<int, int>;
using pll = pair<long long, long long>;

const int inf = 1e9;
const ll inf64 = 1e18;

const ld eps = 1e-9;

struct pt {
    ld x = 0;
    ld y = 0;

    pt operator - (const pt& o) const {
        return {x - o.x, y - o.y};
    }

    pt operator + (const pt& o) const {
        return {x + o.x, y + o.y};
    }

    pt operator * (ld coef) const {
        return {x * coef, y * coef};
    }

    pt operator / (ld coef) const {
        return {x / coef, y / coef};
    }

    ld vector_mul(const pt& o) const {
        return x * o.y - o.x * y;
    }

    ld scalar_mul(const pt& o) const {
        return x * o.x + y * o.y;
    }

    ld sqr_norm() {
        return scalar_mul(*this);
    }

    ld norm() {
        return sqrtl(max(ld(0), sqr_norm()));
    }
};

struct output {
    ld res = 0;

    void print() {
        cout.precision(20);
        cout << fixed;
        cout << res << "\n";
    }

    bool operator == (const output& o) const {
        throw;
    }
};

struct input {
    int n;
    vector<pt> ps;

    input() = default;

    void read() {
        cin >> n;
        ps.resize(n);
        for (auto& p : ps)
            cin >> p.x >> p.y;
    }

    void print() {
    }

    void gen() {
        // use static
    }

    pt intersect_lines(pt a, pt b, pt c, pt d) {
        pt v = b - a;
        pt u = d - c;
        ld t = u.vector_mul(a - c) / v.vector_mul(u);
        return a + v * t;
    }

    bool intersect(vector<pair<pt, pt>> lines) {
        static mt19937 GEN(42);
        shuffle(lines.begin(), lines.end(), GEN);

        vector<pair<pt, pt>> st = {lines[0]};
        pt p = lines[0].first;
        for (int i = 1; i < (int) lines.size(); i++) {
            auto [a, b] = lines[i];
            if ((b - a).vector_mul(p - a) > -eps)
                continue;
            int was1 = 0, was2 = 0;
            pt p1, p2;
            for (int j = 0; j < i; j++) {
                auto [c, d] = lines[j];
                pt q = intersect_lines(a, b, c, d);
                if ((b - a).vector_mul(d - c) > eps) {
                    if (!was1 || (q - p1).norm() < eps || (q - p1).scalar_mul(b - a) / (q - p1).norm() / (b - a).norm() < -eps) {
                        was1 = 1;
                        p1 = q;
                    }
                } else {
                    if (!was2 || (q - p2).norm() < eps || (p2 - q).scalar_mul(b - a) / (p2 - q).norm() / (b - a).norm() < -eps) {
                        was2 = 1;
                        p2 = q;
                    }
                }
                if (was1 && was2) {
                    if ((p1 - p2).norm() < eps || (p2 - p1).scalar_mul(b - a) / (p2 - p1).norm() / (b - a).norm() < -eps) p = p1;
                    else p = p2;
                } else if (was1) p = p1;
                else p = p2;
            }
        }

        // check

        for (auto [a, b] : lines) {
            if ((b - a).vector_mul(p - a) < -eps)
                return false;
        }

        return true;
    }

    bool check(ld coef) {
        vector<pair<pt, pt>> lines;
        for (int k = 1, i = 0; i < n; i++) {
            int j = (i + 1) % n;
            pt u = ps[i] - ps[j];
            while (1) {
                int nk = (k + 1) % n;
                pt v = ps[nk] - ps[k];
                if (v.vector_mul(u) > eps) {
                    k = nk;
                } else {
                    break;
                }
            }
            for (int dk = -1; dk <= -1; dk++) {
                int kk = (k + dk + n) % n;
                if (kk == i || kk == j)
                    continue;
                pt ai = ps[i] + ((ps[kk] - ps[i]) / (coef + 1));
                pt bi = ps[j] + ((ps[kk] - ps[j]) / (coef + 1));
                lines.emplace_back(ai, bi);
            }
        }
        return intersect(lines);
    }

    output fast() {
//        cout << check(1) << " ?\n";
//        return output{-1};
        const int MAX_ITER = 500;
        ld bl = 1, br = 1e6, bm;
        for (int iter = 0; iter < MAX_ITER; iter++) {
            bm = (bl + br) * 0.5;
            if (check(bm)) br = bm;
            else bl = bm;
        }
        ld res = (bl + br) * 0.5;
        return output{res};
    }

    output slow() {
        return output();
    }
};

void test_case() {
    input in;
    in.read();
    output res = in.fast();
    res.print();
}

void work() {
    int t = 1;
    while (t--)
        test_case();
}

void test() {
    for (int t = 1;;t++) {
        input in;
        in.gen();
        input in_fs = in;
        input in_sl = in;
        output fs = in_fs.fast();
        output sl = in_sl.slow();
        if (fs == sl) {
            cout << "OK" << endl;
            fs.print();
            cout << "\n=========" << endl;
        } else {
            cout << "WA " << t << "\n";
            cout << "exp\n";
            sl.print();
            cout << "\n=========\n";
            cout << "fnd\n";
            fs.print();
            cout << "\n=========\n";
            in.print();
            break;
        }
    }
}

int main() {

#ifdef DEBUG
    freopen("input.txt", "r", stdin);
#endif

    ios_base::sync_with_stdio(0);
    cin.tie(0);

    work();
//    test();

    return 0;
}
