#include <bits/stdc++.h>

using namespace std;

using ll = long long;
using ui = unsigned int;
using ull = unsigned long long;
using ld = long double;
using pii = pair<int, int>;
using pll = pair<long long, long long>;

const int inf = 1e9;
const ll inf64 = 1e18;

const ld eps = 1e-8;

struct pt {
    ld x = 0;
    ld y = 0;

    pt operator - (const pt& o) const {
        return {x - o.x, y - o.y};
    }

    pt operator + (const pt& o) const {
        return {x + o.x, y + o.y};
    }

    pt operator * (ld coef) const {
        return {x * coef, y * coef};
    }

    pt operator / (ld coef) const {
        return {x / coef, y / coef};
    }

    ld vector_mul(const pt& o) const {
        return x * o.y - o.x * y;
    }

    ld scalar_mul(const pt& o) const {
        return x * o.x + y * o.y;
    }
};

struct output {
    ld res = 0;

    void print() {
        cout.precision(20);
        cout << fixed;
        cout << res << "\n";
    }

    bool operator == (const output& o) const {
        throw;
    }
};

struct input {
    int n;
    vector<pt> ps;

    input() = default;

    void read() {
        cin >> n;
        ps.resize(n);
        for (auto& p : ps)
            cin >> p.x >> p.y;
    }

    void print() {
    }

    void gen() {
        // use static
    }

    pt intersect_lines(pt a, pt b, pt c, pt d) {
        pt v = b - a;
        pt u = d - c;
        ld t = u.vector_mul(a - c) / v.vector_mul(u);
        return a + v * t;
    }

    bool intersect(vector<pair<pt, pt>> lines) {
        vector<pair<pt, pt>> st;
        for (auto L : lines) {
//            cout << L.first.x << ", " << L.first.y << " (" << L.second.x << ", " << L.second.y << ")\n";
            while ((int) st.size() >= 2) {
                auto L1 = st[(int) st.size() - 2];
                auto L2 = st[(int) st.size() - 1];
                pt p = intersect_lines(L1.first, L1.second, L2.first, L2.second);
                pt q = intersect_lines(L1.first, L1.second, L.first, L.second);
                if ((q - p).scalar_mul(L1.second - L1.first) > eps) break;
                st.pop_back();
            }
            st.push_back(L);
        }
        if ((int) st.size() < 2)
            return false;
        auto L1 = st[(int) st.size() - 2];
        auto L2 = st[(int) st.size() - 1];
        pt p = intersect_lines(L1.first, L1.second, L2.first, L2.second);

        for (auto [a, b] : lines) {
            if ((b - a).vector_mul(p - a) < -eps)
                return false;
        }
        return true;
    }

    bool check(ld coef) {
        vector<pair<pt, pt>> lines;
        for (int k = 1, i = 0; i < n; i++) {
            int j = (i + 1) % n;
            pt u = ps[i] - ps[j];
            while (1) {
                int nk = (k + 1) % n;
                pt v = ps[nk] - ps[k];
                if (v.vector_mul(u) > eps) {
                    k = nk;
                } else {
                    break;
                }
            }
            pt ai = ps[i] * (coef + 1) + ((ps[k] - ps[i]));
            pt bi = ps[j] * (coef + 1) + ((ps[k] - ps[j]));
            lines.emplace_back(ai, bi);
        }
        return intersect(lines);
    }

    output fast() {
//        cout << check(1) << " ?\n";
//        return output{-1};
        const int MAX_ITER = 500;
        ld bl = 1, br = 1e7, bm;
        for (int iter = 0; iter < MAX_ITER; iter++) {
            bm = (bl + br) * 0.5;
            if (check(bm)) br = bm;
            else bl = bm;
        }
        ld res = (bl + br) * 0.5;
        return output{res};
    }

    output slow() {
        return output();
    }
};

void test_case() {
    input in;
    in.read();
    output res = in.fast();
    res.print();
}

void work() {
    int t = 1;
    while (t--)
        test_case();
}

void test() {
    for (int t = 1;;t++) {
        input in;
        in.gen();
        input in_fs = in;
        input in_sl = in;
        output fs = in_fs.fast();
        output sl = in_sl.slow();
        if (fs == sl) {
            cout << "OK" << endl;
            fs.print();
            cout << "\n=========" << endl;
        } else {
            cout << "WA " << t << "\n";
            cout << "exp\n";
            sl.print();
            cout << "\n=========\n";
            cout << "fnd\n";
            fs.print();
            cout << "\n=========\n";
            in.print();
            break;
        }
    }
}

int main() {

#ifdef DEBUG
    freopen("input.txt", "r", stdin);
#endif

    ios_base::sync_with_stdio(0);
    cin.tie(0);

    work();
//    test();

    return 0;
}
