#include <bits/stdc++.h>
 
using namespace std;
 
const long double eps = 1e-8, INF = 1e10;
 
struct point {
    long double x, y;
    point() {}
    point(long double x, long double y): x(x), y(y) {}
    void init() {
        int xx, yy;
        cin >> xx >> yy;
        x = xx, y = yy;
    }
    void print() {
        cout << fixed << x << ' ' << y << endl;
    }
    long double len() {
        return sqrt(x * x + y * y);
    }
    point operator + (point a) {
        return point(x + a.x, y + a.y);
    }
    point operator - (point a) {
        return point(x - a.x, y - a.y);
    }
    point norma() {
        return point(-y, x);
    }
    long double operator * (point a) {
        return x * a.x + y * a.y;
    }
    long double operator ^ (point a) {
        return x * a.y - y * a.x;
    }
    point mul(long double k) {
        return point(x * k, y * k);
    }
    point set_len(long double new_len) {
        return mul(new_len / len());
    }
    point normalize() {
        return set_len(1);
    }
    point turn(long double alpha) {
        return mul(cos(alpha)) + norma().mul(sin(alpha));
    }
    bool operator == (point a) {
        return (fabs(x - a.x) < eps && fabs(y - a.y) < eps);
    }
};
 
struct line {
    point p, v;
    line() {}
    line(point a, point b): p(a), v(b) {}
    bool on_line(point t) {
        return (fabs((t - p) ^ v) < eps);
    }
    bool parallel(line b) {
        return (fabs((v ^ b.v)) < eps);
    }
    point intersec(line b) {
        long double t = ((b.p ^ b.v) - (p ^ b.v)) / (v ^ b.v);
        return p + v.mul(t);
    }
    long double intersection_t(line b) {
        return ((b.p ^ b.v) - (p ^ b.v)) / (v ^ b.v);
    }
    long double dist_line(point a) {
        long double t = ((a * v) - (p * v)) / (v * v);
        return (p + v.mul(t) - a).len();
    }
    long double dist_segm(point a) {
        long double t = ((a * v) - (p * v)) / (v * v);
        if (t >= 0 && t <= 1)
            return (p + v.mul(t) - a).len();
        return min((p - a).len(), (p + v - a).len());
    }
    bool has_on_halfplane(point a) {
        return ((a - p) * v.norma()) > -eps;
    }
    long double get_val(long double x) {
        long double t = (x - p.x) / v.x;
        return p.y + v.y * t;
    }
};
 
vector <point> get_convex(vector <line> &half_planes) {
    sort(half_planes.begin(), half_planes.end(), [](line &lhs, line &rhs) {
        return (lhs.v ^ rhs.v) > 0;
    });
    vector <pair <line, long double>> st;
    for (auto elem : half_planes) {
        while (!st.empty()) {
            auto [l, tt] = st.back();
            if (l.parallel(elem)) {
                if (l.has_on_halfplane(elem.p))
                    st.pop_back();
                else
                    break;
            } else {
                long double t = l.intersection_t(elem);
                if (t > tt) {
                    st.push_back({elem, elem.intersection_t(l)});
                    break;
                }
                st.pop_back();
            }
        }
        if (st.empty())
            st.push_back({elem, -INF});
    }
    vector <point> ans;
    for (auto [l, t] : st) {
        ans.push_back(l.p + l.v.mul(t));
    }
    ans.push_back(st.back().first.p + st.back().first.v.mul(INF));
    return ans;
}
 
line getline(vector <point> &p, int uk) {
    return line(p[uk - 1], p[uk] - p[uk - 1]);
}

line getline2(vector <point> &p, int uk) {
    int n = p.size();
    return line(p[uk], p[(uk + 1) % n] - p[uk]);
}
 
vector <point> halfplanes_intersection(vector <line> half_planes) {
    vector <line> half_planes_up, half_planes_down;
    for (auto elem : half_planes) {
        if (make_pair(elem.v.x, elem.v.y) < make_pair(0.0l, 0.0l))
            half_planes_up.push_back(elem);
        else
            half_planes_down.push_back(elem);
    }
    auto up = get_convex(half_planes_up);
    auto down = get_convex(half_planes_down);
    reverse(up.begin(), up.end());
 
    vector <point> ans_up, ans_down;
    int uk_up = 0, uk_down = 0, sz_up = up.size(), sz_down = down.size();
    bool flag = 0;
    while (uk_up != sz_up && uk_down != sz_down) {
        if (up[uk_up].x < down[uk_down].x) {
            if (uk_down == 0) {
                uk_up++;
                continue;
            }
            bool good = getline(down, uk_down).get_val(up[uk_up].x) < up[uk_up].y;
            if (good ^ flag) {
                ans_up.push_back(getline(down, uk_down).intersec(getline(up, uk_up)));
            }
            if (good)
                ans_up.push_back(up[uk_up]);
            uk_up++;
            flag = good;
        } else {
            if (uk_up == 0) {
                uk_down++;
                continue;
            }
            bool good = getline(up, uk_up).get_val(down[uk_down].x) > down[uk_down].y;
            if (good ^ flag) {
                ans_down.push_back(getline(down, uk_down).intersec(getline(up, uk_up)));
            }
            if (good)
                ans_down.push_back(down[uk_down]);
            uk_down++;
            flag = good;
        }
    }
    reverse(ans_up.begin(), ans_up.end());
    vector <point> ans = ans_down;
    for (auto elem : ans_up)
        ans.push_back(elem);
    return ans;
}
 
long double get_s(vector <point> poly) {
    if (poly.empty())
        return 0;
 
    poly.push_back(poly[0]);
    long double ans = 0;
    for (int i = 1; i < (int) poly.size(); i++) {
        ans += poly[i - 1] ^ poly[i];
    }
    return fabs(ans) / 2;
}
 
 
signed main() {
    //freopen("Desktop/input.txt", "r", stdin);
    ios_base :: sync_with_stdio(0);
    cin.tie(0);
    cout.tie(0);
    cout.precision(20);
    int n;
    cin >> n;
    vector <point> poly(n);
    for (int i = 0; i < n; i++)
        poly[i].init();
 
    vector <int> kek;
    int opt = 0;
    for (int i = 0; i < n; i++) {
        if (getline2(poly, 0).dist_line(poly[i]) > getline2(poly, 0).dist_line(poly[opt]))
            opt = i;
    }
    for (int i = 0; i < n; i++) {
        while (getline2(poly, i).dist_line(poly[(opt + 1) % n]) > getline2(poly, i).dist_line(poly[opt]))
            opt = (opt + 1) % n;
        kek.push_back(opt);
    }
     
    long double ll = 1, rr = INF;
    for (int tt = 0; tt < 100; tt++) {
        long double m = (ll + rr) / 2;
        vector <line> hp;
        for (int i = 0; i < n; i++) {
            int opt = kek[i];
            point a = poly[opt] + (poly[i] - poly[opt]).mul(m / (m + 1));
            point b = poly[opt] + (poly[(i + 1) % n] - poly[opt]).mul(m / (m + 1));
            hp.push_back(line(a, b - a));
        }
        auto kek = halfplanes_intersection(hp);
        if (kek.size() > 2)
            rr = m;
        else
            ll = m;
    }
    cout << fixed << rr << "\n";
}
