#include <iostream>
#include <vector>
#include <algorithm>
#include <set>
#include <cmath>
#include <iomanip>
#include <map>
#include <complex>
#include <queue>
#include <cassert>
#include <chrono>
#include <random>
#include <climits>
#define forn(i, n) for (int i = 0; i < n; ++i)
#define debug(x) cout << #x << " = " << x << endl
#define all(a) begin(a), end(a)
#define sqr(x) ((x) * (x))
//#define int long long

using namespace std;

template<class Iter> 
void print(Iter l, Iter r) {
    cout << "[";
    for (auto it = l; it != r; ++it) {
        if (it != l) {
            cout << ", ";   
        }
        cout << *it;
    }
    cout << "]" << endl;
}

template<class C, class F> 
ostream& operator<<(ostream &out, pair<C, F> p) {
    return out << "(" << p.first << ", " << p.second << ")";
}

using ll = long long;

mt19937_64 rnd(std::chrono::system_clock::now().time_since_epoch().count());

const int N = 4e5 + 40;
const int BUBEN = 350;
const int INF = 1e9;

int n, m;

struct Node {
	int lval, rval;
	int ldp, rdp;
	int max_dp = 0;
	int len;
};

Node t[4 * N];
vector<pair<int, int>> st;

Node merge(Node left, Node right) {
	Node ret;
	ret.lval = left.lval;
	ret.rval = right.rval;
	ret.len = left.len + right.len;

	ret.ldp = left.ldp;
	if (right.lval == left.rval + 1 && left.ldp == left.len) {
		ret.ldp += right.ldp;
	}

	ret.rdp = right.rdp;
	if (right.lval == left.rval + 1 && right.rdp == right.len) {
		ret.rdp += left.rdp;
	}

	if (right.lval == left.rval + 1) {
		ret.max_dp = left.rdp + right.ldp;
	}

	ret.max_dp = max({ret.max_dp, left.max_dp, right.max_dp, ret.ldp, ret.rdp});
	return ret;
}

void build(int i, int tl, int tr) {
	if (tl + 1 == tr) {
		t[i].lval = t[i].rval = st[tl].first;
		t[i].ldp = t[i].rdp = t[i].max_dp = st[tl].second > 0;
		t[i].len = 1;
		return;
	}
	int md = (tl + tr) / 2;
	build(i * 2, tl, md);
	build(i * 2 + 1, md, tr);
	t[i] = merge(t[i * 2], t[i * 2 + 1]);
}

void modifyPoint(int i, int tl, int tr, int pt) {
	if (tl + 1 == tr) {
		t[i].lval = t[i].rval = st[tl].first;
		t[i].ldp = t[i].rdp = t[i].max_dp = st[tl].second > 0;
		t[i].len = 1;
		return;
	}
	int md = (tl + tr) / 2;
	if (pt < md) {
		modifyPoint(i * 2, tl, md, pt);
	} else {
		modifyPoint(i * 2 + 1, md, tr, pt);
	}
	t[i] = merge(t[i * 2], t[i * 2 + 1]);
}

void show_do(int i, int tl, int tr) {
	debug(tl);
	debug(tr);
	debug(t[i].len);
	debug(t[i].max_dp);
	debug(t[i].lval);
	debug(t[i].rval);
	debug(t[i].ldp);
	debug(t[i].rdp);
	cout << "\n";
	if (tl + 1 == tr) return;
	int md = (tl + tr) / 2;
	show_do(i * 2, tl, md);
	show_do(i * 2 + 1, md, tr);
}

void solve() {
    cin >> n >> m;

    vector<int> a(n);
    vector<pair<int, int>> changes;
    map<int, int> cnt;

    forn(i, n) {
        cin >> a[i];
        int need = m - a[i] % m;
        if (need < m) {
            changes.push_back({need, a[i] / m});
        }
        cnt[a[i] / m]++;
        cnt[a[i] / m + 1];
    }

    st.clear();
    for (auto &[x, y] : cnt) {
    	st.push_back({x, y});
    }

    build(1, 0, st.size());
    map<int, int> pos;

    for (int i = 0; i < st.size(); ++i)
    	pos[st[i].first] = i;

    sort(all(changes));

    int res = t[1].max_dp;
    int shift = 0;

    for (int i = 0; i < changes.size(); ) {
    	int j = i;
    	while (j < changes.size() && changes[j].first == changes[i].first) {
    		auto pos1 = pos[changes[j].second];
    		auto pos2 = pos[changes[j].second + 1];

    		st[pos1].second--;
            st[pos2].second++;
            modifyPoint(1, 0, st.size(), pos1);
            modifyPoint(1, 0, st.size(), pos2);
            ++j;
    	}

    	if (t[1].max_dp > res) {
    		res = t[1].max_dp;
    		shift = changes[i].first;
    	}

    	i = j;
    }

    cout << res << " " << shift << "\n";
}

signed main() {
    ios::sync_with_stdio(false);
    cin.tie(0); 

    int t;
    cin >> t;
    while (t--) {
        solve();
    }

    return 0;
}