#include <iostream>
#include <vector>
#include <string>
#include <algorithm>
#include <unordered_map>
#include <unordered_set>

using namespace std;
using ll = long long;

struct Colors {
    int w, b;
    int i;
};

struct Edge {
    int v, u;
    char c;
};

void solve() {
    int n;
    cin >> n;
    vector<Colors> colors(n);
    for (int i = 0; i < n; ++i) {
        auto& c = colors[i];
        c.i = i;
        cin >> c.w >> c.b;
    }

    sort(colors.begin(), colors.end(), [&](const auto& lhs, const auto& rhs) {
        return (lhs.w + lhs.b) < (rhs.w + rhs.b);
    });

    vector<int> w_pool, b_pool;
    vector<Edge> edges;
    edges.reserve(n - 1);

    for (const auto& c : colors) {
        int i = c.i;
        //cerr << "looking at i=" << i << " w=" << c.w << " b=" << c.b << endl;
        if (c.w == 0 && c.b == 0) {
            if (n == 1) {
                cout << "Yes\n";
            } else {
                cout << "No\n";
            }
            return;
        }

        int w = c.w;
        int b = c.b;

        while (w + b > 1) {
            if (w >= 1 && !w_pool.empty()) {
                --w;
                edges.push_back(Edge { i, w_pool.back(), 'W' });
                w_pool.pop_back();
                continue;
            } else if (b >= 1 && !b_pool.empty()) {
                --b;
                edges.push_back(Edge { i, b_pool.back(), 'B' });
                b_pool.pop_back();
                continue;
            } else {
                cout << "No\n";
                return;
            }
        }

        if (w == 1) {
            w_pool.push_back(i);
            //cerr << "adding to w_pool\n";
        } else {
            b_pool.push_back(i);
            //cerr << "adding to b_pool\n";
        }
    }

    if (w_pool.size() % 2 == 1 || b_pool.size() % 2 == 1) {
        cout << "No\n";
        return;
    }

    while (!w_pool.empty()) {
        auto u = w_pool.back(); w_pool.pop_back();
        auto v = w_pool.back(); w_pool.pop_back();
        edges.push_back(Edge { u, v, 'W' });
    }

    while (!b_pool.empty()) {
        auto u = b_pool.back(); b_pool.pop_back();
        auto v = b_pool.back(); b_pool.pop_back();
        edges.push_back(Edge { u, v, 'B' });
    }

    if (edges.size() + 1 != n) {
        cout << "No\n";
        return;
    }

    sort(colors.begin(), colors.end(), [&](const auto& lhs, const auto& rhs) {
        return lhs.i < rhs.i;
    });

    for (const auto& e : edges) {
        if (e.c == 'B') colors[e.u].b--, colors[e.v].b--;
        if (e.c == 'W') colors[e.u].w--, colors[e.v].w--;
    }

    for (const auto& c : colors) {
        if (c.b || c.w) {
            cout << "No\n";
            return;
        }
    }

    cout << "Yes\n";
    for (const auto& e : edges) {
        cout << e.u + 1 << " " << e.v + 1 << " " << e.c << '\n';
    }
}

int main() {
    cin.tie(nullptr);
    ios::sync_with_stdio(false);

    int t;
    cin >> t;
    for (int i = 0; i < t; ++i) {
        solve();
    }
    return 0;
}
