#include <iostream>
#include <vector>
#include <algorithm>
#include <map>
#include <unordered_map>
#include <cassert>

using namespace std;

typedef long long ll;

static const int MAXN = 2e9 + 1;

struct tree {
    tree() = delete;
    struct node {
        int pref = 0, suf = 0, res = 0, sum = 0, sz = 0, nonempty = 0;
        int l = -1, r = -1;
        node() = delete;
        node(int sz) : sz(sz) {
        }
    };
    vector <node> nodes;

    void create_childs(int v, int lv, int rv) {
        if (nodes[v].l == -1) {
            int mv = (lv + rv) / 2;
            nodes[v].l = nodes.size();
            nodes.emplace_back(mv - lv);
            nodes[v].r = nodes.size();
            nodes.emplace_back(rv - mv);
        }
    }

    void merge(int v) {
        node &n = nodes[v];
        if (nodes[v].l == -1 && nodes[v].r == -1) {
            assert(false);
        }
        node &l = nodes[nodes[v].l];
        node &r = nodes[nodes[v].r];
        n.pref = l.pref;
        n.nonempty = l.nonempty + r.nonempty;
        if (l.nonempty == l.sz) {
            n.pref = max(n.pref, l.sz + r.pref);
        }
        n.suf = r.suf;
        if (r.nonempty == r.sz) {
            n.suf = max(n.suf, r.sz + l.suf);
        }
        n.res = max(l.res, r.res);
        n.res = max(n.res, n.suf);
        n.res = max(n.res, n.pref);
        n.res = max(n.res, l.suf + r.pref);
        n.sum = l.sum + r.sum;
        if (n.sz == n.nonempty) {
            n.res = n.nonempty;
        }
    }

    tree(vector <int> const& points) {
        nodes.reserve(points.size() * 4);
        nodes.emplace_back(MAXN);
        for (int i : points) add(i, 1);
    }

    void add(int x, int val) {
        add(0, 0, MAXN, x, val);
    }

    int get_streak(int v = 0, int lv = 0, int rv = MAXN, int l = 0, int r = MAXN) {
        return nodes[0].res;
//        if (lv <= l && r <= rv) {
//            return nodes[v].res;
//        }
//        if (rv <= l || r <= lv) {
//            return 0;
//        }
//        create_childs(v, lv, rv);
//        int mv = (lv + rv) / 2;
//        int ln = nodes[v].l, rn = nodes[v].r;
//        get_streak(ln, lv, mv, l, r);
//        get_streak(rn, mv, rv, l, r);
//        merge(v);
//        return nodes[v].res;
    }

    void add(int v, int lv, int rv, int x, int delta) {
        if (lv + 1 == rv) {
            node &n = nodes[v];
            n.sum += delta;
            int sign = (n.sum > 0);
            nodes[v].pref = nodes[v].suf = nodes[v].res = nodes[v].nonempty = sign;
            return;
        }
        create_childs(v, lv, rv);
        int mv = (lv + rv) / 2;
        if (x < mv) {
            add(nodes[v].l, lv, mv, x, delta);
        } else {
            add(nodes[v].r, mv, rv, x, delta);
        }
        merge(v);
    }
};

int main() {
#ifdef LOCAL
    freopen("input.txt", "r", stdin);
#endif
    ios::sync_with_stdio(false);
    cin.tie(nullptr);
    int ttt;
    cin >> ttt;
    for (int q = 0; q < ttt; q++) {
        int n, m;
        cin >> n >> m;
        vector <int> points(n);
        vector <pair <int, int>> event(n);
        for (int i = 0; i < n; i++) {
            int p;
            cin >> p;
            points[i] = p / m;
            event[i] = {m - p % m, i};
        }
        tree t(points);
        int ans = t.get_streak();
        int tz = 0;
        sort(event.begin(), event.end());
        int prev = -100;
        for (int i = 0; i < event.size(); i++) {
            if (event[i].first == m) break;
            int day = points[event[i].second];
            t.add(day, -1);
            t.add(day + 1, 1);
            if (prev != event[i].first) {
                int tmp = t.get_streak();
                if (ans < tmp) {
                    ans = tmp;
                    tz = event[i].first;
                }
            }
            prev = event[i].first;
        }
        int tmp = t.get_streak();
        if (ans < tmp) {
            ans = tmp;
            tz = event.back().first;
        }
        cout << ans << ' ' << tz << '\n';
    }
    return 0;
}