#include <iostream>
#include <algorithm>
#include <vector>
#include <iomanip>
#include <map>
#include <set>
#include <fstream>
#include <string>
#include <bitset>
#include <ctime>
#include <random>
#include <iterator>
#include <cmath>
#include <deque>
#include <queue>

using namespace std;

ifstream fin("input.txt");
ofstream fout("output.txt");

using ll = long long;
using ld = long double;
using ull = unsigned long long;

ll const inf = 1e18;

random_device rd;
mt19937 mersenne(rd());

struct Bor 
{
	struct Node
	{
		ll dp = 0;
		pair<char, ll> prev;
		map<char, ll> children;
		set<pair<ll, ll>> priority;

		Node(char c, ll pr)
		{
			prev = { c,pr };
		}
	};

	vector<Node> tree;
	ll root = 0;

	Bor() 
	{
		tree.push_back(Node(' ', - 1));
	}

	void add(ll node, string& s, ll i)
	{
		tree[node].dp++;
		if (i == s.size())
		{
			return;
		}
		if (!tree[node].children.count(s[i]))
		{
			tree.push_back(Node(s[i], node));
			tree[node].children[s[i]] = { tree.size() - 1 };
			tree[node].priority.insert({ -0, tree.size() - 1 });
		}
		ll child = tree[node].children[s[i]];
		ll dp = tree[child].dp;
		tree[node].priority.erase({ -dp, child });
		dp++;
		tree[node].priority.insert({ -dp, child });
		add(child, s, i + 1);
	}

	void add(string s)
	{
		ll node = 0;
		ll i = 0;
		while (true)
		{
			tree[node].dp++;
			if (i == s.size())
			{
				return;
			}
			if (!tree[node].children.count(s[i]))
			{
				tree.push_back(Node(s[i], node));
				tree[node].children[s[i]] = { tree.size() - 1 };
				tree[node].priority.insert({ -0, tree.size() - 1 });
			}
			ll child = tree[node].children[s[i]];
			ll dp = tree[child].dp;
			tree[node].priority.erase({ -dp, child });
			dp++;
			tree[node].priority.insert({ -dp, child });
			node = child;
			i = i + 1;
		}
	}

	void unite()
	{
		vector<pair<ll,ll>> ntr = vector<pair<ll, ll>>(tree.size());
		for (int i = 0; i < ntr.size(); ++i)
			ntr[i] = { -tree[i].dp,i };
		sort(ntr.begin(), ntr.end());

		for (auto& mem : ntr)
		{
			ll node = mem.second;
			if (tree[node].children.size() == 1)
			{
				ll child = tree[node].children.begin()->second;
				if (tree[node].dp != tree[child].dp)
					return;
				ll prev = tree[node].prev.second;
				char c = tree[node].prev.first;
				tree[child].prev = { c, prev };
				if (prev != -1)
				{
					tree[prev].children.erase(c);
					tree[prev].children[c] = child;
					tree[prev].priority.erase({ -tree[node].dp, node });
					tree[prev].priority.insert({ -tree[child].dp, child });
				}
			}
		}

	}
	
	void dfs(ll v, ll p, ll k, ll& ans)
	{
		while (!tree[v].priority.empty())
		{
			if (tree[v].dp <= k)
			{
				if (p == -1 && tree[v].dp > 0)
				{
					++ans;
				}
				return;
			}
			ll u = tree[v].priority.begin()->second;
			if (tree[u].dp > k)
				dfs(u, v, k, ans);
			else
			{
				ll del = tree[u].dp;
				if (tree[u].dp > 0)
					++ans;
				ll c = u;
				u = tree[u].prev.second;
				while (u != -1)
				{
					tree[u].priority.erase({ -tree[c].dp, c });
					tree[c].dp -= del;
					tree[u].priority.insert({ -tree[c].dp, c });
					c = u;
					u = tree[u].prev.second;
				}
				tree[root].dp -= del;
			}
		}
	}

};

signed main()
{
	ios::sync_with_stdio(false);
	cin.tie(0);
	cout.tie(0);

	ll n, k; cin >> n >> k;
	Bor bor;

	for (int i = 0; i < n; ++i)
	{
		string s; cin >> s;
		bor.add(s);
	}
	ll ans = 0;
	vector<ll> del(bor.tree.size(), 0);
	bor.unite();
	bor.dfs(0, -1, k, ans);
	cout << ans << '\n';

	return 0;
}