import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.*;

class MyMap implements Comparable {
    int amount;
    StringTree tree;

    public MyMap(int amount, StringTree tree) {
        this.amount = amount;
        this.tree = tree;
    }

    @Override
    public int compareTo(Object o) {
        return Integer.compare(amount, ((MyMap) o).amount);
    }
}

class StringTree implements Comparable {
    static HashMap<StringTree, Integer> numbers = new HashMap<>();
    TreeSet<StringTree> subTrees = new TreeSet<>();
    int numberOfStrings;
    String rootString = "";
    StringTree parent;

    public StringTree(StringTree parent) {
        this.parent = parent;
    }

    @Override
    public String toString() {
        StringBuilder result = new StringBuilder();
        result.append("-----\n");
        for (StringTree tree : subTrees) {
            result.append(tree.rootString);
            result.append('\n');
            result.append(tree.toString());
        }
        result.append("\n");
        result.append("------\n");
        return result.toString();
    }

    @Override
    public int compareTo(Object o) {
        return this.rootString.compareTo(((StringTree) o).rootString);
    }

    void decreaseAmount(int i) {
        numberOfStrings -= i;
        numbers.replace(this, numberOfStrings);
        if (parent != null) {
            parent.decreaseAmount(i);
        }
    }

    void removeNode() {
        if (parent != null) {
            parent.subTrees.remove(this);
            decreaseAmount(numberOfStrings);
            numbers.remove(this);
            return;
        }
        numberOfStrings = 0;
    }

    void placeString(String s) {
        numberOfStrings++;
        numbers.replace(this, numberOfStrings);
        boolean flag = false;
        boolean flagFullEqual = false;
        boolean flagStringFullEqual = false;
        String buffer = "";
        String suffix = "";
        int rootStringLength;
        String rootString;
        StringTree bufferTree = null;
        for (StringTree tree : subTrees) {
            rootString = tree.rootString;
            rootStringLength = rootString.length();
            for (int i = 0; i < s.length(); i++) {
                if (i < rootStringLength) {
                    if (s.charAt(i) == rootString.charAt(i)) {
                        if (i == 0) {
                            flag = true;
                            bufferTree = tree;
                        }
                        if (i == s.length() - 1) {
                            flagStringFullEqual = true;
                            buffer = s;
                        }
                    } else {
                        buffer = s.substring(0, i);
                        suffix = s.substring(i);
                        break;
                    }
                } else {
                    bufferTree = tree;
                    buffer = s.substring(0, i);
                    suffix = s.substring(i);
                    flagFullEqual = true;
                    break;
                }
            }
            if (flag) {
                break;
            }
        }
        if (flagStringFullEqual) {
            if (s.equals(bufferTree.rootString)) {
                bufferTree.numberOfStrings++;
                numbers.replace(bufferTree, bufferTree.numberOfStrings);
            } else {
                StringTree newNode = new StringTree(this);
                newNode.rootString = s;
                bufferTree.rootString = bufferTree.rootString.substring(s.length());
                newNode.subTrees.add(bufferTree);
                newNode.numberOfStrings = bufferTree.numberOfStrings + 1;
                numbers.put(newNode, newNode.numberOfStrings);
                subTrees.remove(bufferTree);
                subTrees.add(newNode);
            }
            return;
        } else if (flagFullEqual) {
            bufferTree.placeString(suffix);
            return;
        } else if (flag) {
            StringTree newNode = new StringTree(this);
            newNode.rootString = buffer;
            bufferTree.rootString = bufferTree.rootString.substring(buffer.length());
            newNode.subTrees.add(bufferTree);
            newNode.numberOfStrings = bufferTree.numberOfStrings + 1;
            numbers.put(newNode, newNode.numberOfStrings);
            StringTree newChild = new StringTree(this);
            newChild.rootString = suffix;
            newChild.numberOfStrings = 1;
            numbers.put(newChild, 1);
            subTrees.remove(bufferTree);
            newNode.subTrees.add(newChild);
            subTrees.add(newNode);
            return;
        }
        StringTree newChild = new StringTree(this);
        newChild.rootString = s;
        newChild.numberOfStrings = 1;
        numbers.put(newChild, 1);
        subTrees.add(newChild);
    }
}

class PC {
    public static void main(String[] args) throws IOException {
        BufferedReader reader = new BufferedReader(new InputStreamReader(System.in));
        StringTokenizer stk = new StringTokenizer(reader.readLine());
        StringTree mainRoot = new StringTree(null);
        int n = Integer.parseInt(stk.nextToken());
        int k = Integer.parseInt(stk.nextToken());
        String input;
        StringTree.numbers.put(mainRoot, 0);
        for (int i = 0; i < n; i++) {
            input = reader.readLine();
            mainRoot.placeString(input);
        }
        Integer[] a;
        StringTree[] tree;
        MyMap[] m;
        int counter = 0;
        while (mainRoot.numberOfStrings != 0) {
            a = new Integer[StringTree.numbers.size()];
            tree = new StringTree[StringTree.numbers.size()];
            StringTree.numbers.keySet().toArray(tree);
            StringTree.numbers.values().toArray(a);
            m = new MyMap[a.length];
            for (int i = 0; i < m.length; i++) {
                m[i] = new MyMap(a[i], tree[i]);
            }
            Arrays.sort(m);
            int r = binarySearch(m, k);
            m[r].tree.removeNode();
            counter++;
        }
        System.out.println(counter);
    }

    static int binarySearch(MyMap[] a, int target) {
        int i = 0;
        int j = a.length;
        while (Math.abs(i - j) > 1) {
            if (a[(i + j) / 2].amount == target) {
                return (i + j) / 2;
            }
            if (a[(i + j) / 2].amount < target) {
                i = (i + j) / 2;
            } else {
                j = (i + j) / 2;
            }
        }
        return i;
    }
}
