#include <iostream>
#include <vector>
#include <queue>
#include <map>
#include <algorithm>
using namespace std;

map<long long, map<long long, long long>> colors;

void add_edge(vector<int> adj[],
              int src, int dest)
{
    adj[src].push_back(dest);
    adj[dest].push_back(src);
}

void find_paths(vector<vector<int> >& paths,
                vector<int>& path,
                vector<int> parent[],
                int n, int u)
{
    if (u == -1) {
        paths.push_back(path);
        return;
    }
    for (int par : parent[u]) {
        path.push_back(u);
        find_paths(paths, path, parent,
                   n, par);
        path.pop_back();
    }
}

void bfs(vector<int> adj[],
         vector<int> parent[],
         int n, int start)
{
    vector<int> dist(n, INT_MAX);

    queue<int> q;
    q.push(start);
    parent[start] = { -1 };
    dist[start] = 0;
    while (!q.empty()) {
        int u = q.front();
        q.pop();
        for (int v : adj[u]) {
            if (dist[v] > dist[u] + 1) {
                dist[v] = dist[u] + 1;
                q.push(v);
                parent[v].clear();
                parent[v].push_back(u);
            }
            else if (dist[v] == dist[u] + 1) {
                parent[v].push_back(u);
            }
        }
    }
}

void print_paths(vector<int> adj[],
                 int n, int start, int end)
{
    vector<vector<int> > paths;
    vector<int> path;
    vector<int> parent[n];
    bfs(adj, parent, n, start);
    find_paths(paths, path, parent, n, end);
    for (auto& v : paths) {
        reverse(v.begin(), v.end());
    }
    long long most = -1;
    long long index = -1;
    long long cnt = 0;
    for (auto& v: paths){
        long long min_caleido = 10000000000;
        long long max_caleido = -1;
        for (int i = 0; i < v.size() - 1; i++){
            min_caleido = min(min_caleido, colors[v[i]][v[i+1]]);
            max_caleido = max(max_caleido, colors[v[i]][v[i+1]]);
        }
        if (max_caleido - min_caleido > most){
            most = max_caleido - min_caleido;
            index = cnt;
        }
        cnt++;
    }
    std::cout << paths[index].size() - 1 << endl;
    for (auto i: paths[index]){
        cout << i + 1 << ' ';
    }
    cout << endl;
}

int main()
{
    int n, m;
    cin >> n >> m;
    vector<int> adj[n];
    for (int i = 0; i < m; i++){
        int st, end, color;
        cin >> st >> end >> color;
        add_edge(adj, st - 1, end - 1);
        if (colors[st - 1].empty())
            colors[st - 1] = map<long long, long long>();
        colors[st-1][end-1] = color;
        if (colors[end - 1].empty())
            colors[end - 1] = map<long long, long long>();
        colors[end-1][st-1] = color;

    }
    int src = 0;
    int dest = n - 1;
    print_paths(adj, n, src, dest);

    return 0;
}
