﻿using System;
using System.Collections.Generic;
using System.Linq;

namespace ConsoleApplication1
{
    internal class Program
    {
        public static void Main(string[] args)
        {
            var testsCount = int.Parse(Console.ReadLine());
            var tests = new (string, string)[testsCount];
            for (int i = 0; i < testsCount; i++)
            {
                tests[i] = (Console.ReadLine(), Console.ReadLine());
            }

            foreach (var test in tests)
            {
                var split = test.Item1.Split().Select(int.Parse).ToArray();
                var n = split[0];
                var m = split[1];
                var timestamps = test.Item2.Split().Select(int.Parse).ToArray();
                // var possibleStreaks = new List<List<int>>();
                // var currentStreak = new List<int>();
                // currentStreak.Add(timestamps[0]);
                // var m2 = m * 2;
                // for (int i = 1; i < timestamps.Length; i++)
                // {
                //     if (timestamps[i] - timestamps[i - 1] < m2)
                //         currentStreak.Add(timestamps[i]);
                //     else
                //     {
                //         possibleStreaks.Add(currentStreak);
                //         currentStreak = new List<int>();
                //         currentStreak.Add(timestamps[i]);
                //     }
                // }
                //
                // possibleStreaks.Add(currentStreak);

                var (maxDays, answerM) = GetMaxDays(timestamps, m);
                Console.WriteLine($"{maxDays} {answerM}");
            }
        }

        private static (int maxDays, int answerM) GetMaxDays(int[] timestamps, int m)
        {
            var states = new List<State>
            {
                new State
                {
                    Timestamp = timestamps[0],
                    PossibleTimezones = new[] {new Range {From = 0, To = m - 1}},
                    StreakDays = 1
                }
            };

            for (int i = 1; i < timestamps.Length; i++)
            {
                var newStates = new List<State>();
                var previousTimestamp = timestamps[i - 1];
                var currentTimestamp = timestamps[i];

                foreach (var state in states.Where(p => p.Timestamp == previousTimestamp))
                {
                    var (oneDay, nextDay) = GetRanges(previousTimestamp, currentTimestamp, m);

                    var newOneDayRanges = state.PossibleTimezones
                        .SelectMany(range => oneDay.Select(range.Intersect))
                        .Where(x => x != null)
                        .ToArray();
                    if (newOneDayRanges.Any())
                    {
                        newStates.Add(new State
                        {
                            StreakDays = state.StreakDays,
                            PossibleTimezones = newOneDayRanges,
                            Timestamp = currentTimestamp
                        });
                    }

                    var newNextDayRanges = state.PossibleTimezones
                        .SelectMany(range => nextDay.Select(range.Intersect))
                        .Where(x => x != null)
                        .ToArray();
                    if (newNextDayRanges.Any())
                    {
                        newStates.Add(new State
                        {
                            StreakDays = state.StreakDays + 1,
                            PossibleTimezones = newNextDayRanges,
                            Timestamp = currentTimestamp
                        });
                    }
                }

                newStates.Add(new State
                {
                    Timestamp = currentTimestamp,
                    PossibleTimezones = new[] {new Range {From = 0, To = m - 1}},
                    StreakDays = 1
                });
                states.AddRange(newStates);
                newStates.Clear();
            }

            var maxStreak = states.OrderByDescending(s => s.StreakDays).First();
            return (maxStreak.StreakDays, maxStreak.PossibleTimezones.First().From);
        }

        private static (List<Range> oneDay, List<Range> nextDay) GetRanges(int previousTimestamp, int nextTimestamp,
            int m)
        {
            var oneDay = new List<Range>();
            var nextDay = new List<Range>();
            var prevRanges = GetRanges(previousTimestamp, m).Select((range, i) => (range, previousTimestamp / m + i))
                .ToArray();
            var nextRanges = GetRanges(nextTimestamp, m).Select((range, i) => (range, nextTimestamp / m + i)).ToArray();

            foreach (var (prevRange, dayPrev) in prevRanges)
            {
                foreach (var (nextRange, dayNext) in nextRanges)
                {
                    var intersect = prevRange.Intersect(nextRange);
                    if (intersect == null)
                        continue;
                    if (dayPrev == dayNext)
                        oneDay.Add(intersect);
                    else if (Math.Abs(dayPrev - dayNext) == 1)
                        nextDay.Add(intersect);
                }
            }

            return (oneDay, nextDay);
        }

        private static IEnumerable<Range> GetRanges(int timestamp, int m)
        {
            var offset = timestamp % m;
            yield return new Range {From = 0, To = m - 1 - offset};
            if (offset != 0)
                yield return new Range {From = m - offset, To = m - 1};
        }

        private class State
        {
            public int Timestamp { get; set; }
            public int StreakDays { get; set; }
            public Range[] PossibleTimezones { get; set; }
        }

        private class Range
        {
            public int From { get; set; }
            public int To { get; set; }

            public Range Intersect(Range other)
            {
                var from = Math.Max(From, other.From);
                var to = Math.Min(To, other.To);
                if (from > to)
                    return null;
                return new Range {From = from, To = to};
            }
        }
    }
}