#include <iostream>
#include <string>
#include <map>

using namespace std;

const int MaxSumLength = 300500;
const int AlphabetSize = 26;

struct Node {
    int go[AlphabetSize] = {};
    int words = 0;
    int from = 0;
};

Node t[MaxSumLength];
int treeSize = 0;

int createNewTransition(int v, char c) {
    treeSize++;
    t[v].go[c - 'a'] = treeSize;
    t[treeSize].from = v;
    return treeSize;
}

bool canGo(int v, char c) {
    return t[v].go[c - 'a'] != 0;
}

int go(int v, char c) {
    return t[v].go[c - 'a'];
}

void truncate(int v, char c) {
    int size = t[t[v].go[c - 'a']].words;
    t[v].words -= size;
    while (v != 0) {
        v = t[v].from;
        t[v].words -= size;
    }
    t[v].go[c - 'a'] = 0;
}

void insert(const string &s) {
    int v = 0;
    t[0].words++;
    for (auto c: s) {
        if (!canGo(v, c)) {
            v = createNewTransition(v, c);
        } else {
            v = go(v, c);
        }
        t[v].words++;
    }
}


int next_command(const int &v, const int &k) {
    char route = 'a';
    int max = 0;
    int num = 0;
    bool flag = false;
    for (int i = 0; i < AlphabetSize; ++i) {
        if (t[v].go[i] != 0) {
            if (t[t[v].go[i]].words > k) {
                num += next_command(t[v].go[i], k);
                flag = true;
            } else if (t[t[v].go[i]].words > max) {
                route = char(i + 'a');
                max = t[t[v].go[i]].words;
            }
        }
    }
    if (!flag) {
        truncate(v, route);
        return 1;
    }
    return num;
}


int main() {
    int n, k;
    cin >> n >> k;
    for (int i = 0; i < n; ++i) {
        string s;
        cin >> s;
        insert(s);
    }
    int num = 0;
    while (t[0].words > k) {
        num += next_command(0, k);
    }
    if (t[0].words != 0) {
        num++;
    }
    cout << num;
}